[Lldb-commits] [lldb] r105695 - in /lldb/trunk/include/lldb: Core/FileSpec.h Core/STLUtils.h Core/Stream.h Symbol/Block.h

Eli Friedman eli.friedman at gmail.com
Wed Jun 9 00:14:21 PDT 2010


Author: efriedma
Date: Wed Jun  9 02:14:21 2010
New Revision: 105695

URL: http://llvm.org/viewvc/llvm-project?rev=105695&view=rev
Log:
More random error/warning fixes.


Modified:
    lldb/trunk/include/lldb/Core/FileSpec.h
    lldb/trunk/include/lldb/Core/STLUtils.h
    lldb/trunk/include/lldb/Core/Stream.h
    lldb/trunk/include/lldb/Symbol/Block.h

Modified: lldb/trunk/include/lldb/Core/FileSpec.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Core/FileSpec.h?rev=105695&r1=105694&r2=105695&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Core/STLUtils.h (original)
+++ lldb/trunk/include/lldb/Core/STLUtils.h Wed Jun  9 02:14:21 2010
@@ -11,7 +11,7 @@
 #define liblldb_STLUtils_h_
 #if defined(__cplusplus)
 
-#include <ext/hash_fun.h>
+#include "llvm/ADT/StringExtras.h"
 #include <string.h>
 
 #include <map>
@@ -66,7 +66,7 @@
 {
     size_t operator()( const std::string& x ) const
     {
-        return __gnu_cxx::hash<const char*>()( x.c_str() );
+        return llvm::HashString(x);
     }
 };
 

Modified: lldb/trunk/include/lldb/Core/Stream.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Core/Stream.h?rev=105695&r1=105694&r2=105695&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Core/Stream.h (original)
+++ lldb/trunk/include/lldb/Core/Stream.h Wed Jun  9 02:14:21 2010
@@ -13,6 +13,7 @@
 
 #include "lldb/lldb-private.h"
 #include "lldb/Core/Flags.h"
+#include <cstdarg>
 
 namespace lldb_private {
 
@@ -31,7 +32,7 @@
         eVerbose    = (1 << 0), ///< If set, verbose logging is enabled
         eDebug      = (1 << 1), ///< If set, debug logging is enabled
         eAddPrefix  = (1 << 2), ///< Add number prefixes for binary, octal and hex when eBinary is clear
-        eBinary     = (1 << 3), ///< Get and put data as binary instead of as the default string mode.
+        eBinary     = (1 << 3)  ///< Get and put data as binary instead of as the default string mode.
     };
 
     //------------------------------------------------------------------

Modified: lldb/trunk/include/lldb/Symbol/Block.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Symbol/Block.h?rev=105695&r1=105694&r2=105695&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Symbol/Block.h (original)
+++ lldb/trunk/include/lldb/Symbol/Block.h Wed Jun  9 02:14:21 2010
@@ -49,7 +49,7 @@
     /// Enumeration values for special and invalid Block User ID
     /// values.
     //------------------------------------------------------------------
-    typedef enum
+    enum
     {
         RootID = LLDB_INVALID_UID - 1,  ///< The Block UID for the root block
         InvalidID = LLDB_INVALID_UID        ///< Invalid Block UID.





More information about the lldb-commits mailing list
--- lldb/trunk/include/lldb/Core/FileSpec.h (original)
+++ lldb/trunk/include/lldb/Core/FileSpec.h Wed Jun  9 02:14:21 2010
@@ -37,8 +37,8 @@
         eFileTypePipe,
         eFileTypeRegular,
         eFileTypeSocket,
-        eFileTypeSymbolicLink,
-    };
+        eFileTypeSymbolicLink
+    } FileType;
 
     FileSpec();
 
@@ -351,7 +351,7 @@
     ///
     /// @param[in] length
     ///     The size in bytes that should be mapped starting \a offset
     ///     bytes into the file. If \a length is \c SIZE_T_MAX, map
     ///     as many bytes as possible.
     ///
     /// @return
@@ -360,7 +360,7 @@
     ///     pointer must be checked prior to using it.
     //------------------------------------------------------------------
     lldb::DataBufferSP
-    MemoryMapFileContents (off_t offset = 0, size_t length = SIZE_T_MAX) const;
+    MemoryMapFileContents (off_t offset = 0, size_t length = SIZE_MAX) const;
 
     //------------------------------------------------------------------
     /// Read part of, or the entire contents of, a file into a heap based data buffer.
@@ -381,7 +381,7 @@
     ///
     /// @param[in] length
     ///     The size in bytes that should be mapped starting \a offset
     ///     bytes into the file. If \a length is \c SIZE_T_MAX, map
     ///     as many bytes as possible.
     ///
     /// @return
@@ -390,7 +390,7 @@
     ///     pointer must be checked prior to using it.
     //------------------------------------------------------------------
     lldb::DataBufferSP
-    ReadFileContents (off_t offset = 0, size_t length = SIZE_T_MAX) const;
+    ReadFileContents (off_t offset = 0, size_t length = SIZE_MAX) const;
 
     //------------------------------------------------------------------
     /// Change the file specificed with a new path.
@@ -351,7 +351,7 @@
     /// @param[in] length
     ///     The size in bytes that should be mapped starting \a offset
-    ///     bytes into the file. If \a length is \c SIZE_T_MAX, map
+    ///     bytes into the file. If \a length is \c SIZE_MAX, map
     ///     as many bytes as possible.
     ///
@@ -381,7 +381,7 @@
     /// @param[in] length
     ///     The size in bytes that should be mapped starting \a offset
-    ///     bytes into the file. If \a length is \c SIZE_T_MAX, map
+    ///     bytes into the file. If \a length is \c SIZE_MAX, map
     ///     as many bytes as possible.
     ///

Modified: lldb/trunk/include/lldb/Core/STLUtils.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Core/STLUtils.h?rev=105695&r1=105694&r2=105695&view=diff
==============================================================================